[Python-modules-commits] [willow] 03/11: Added loader for .bmp files

Christopher Stuart Hoskin mans0954 at moszumanska.debian.org
Tue Dec 5 23:12:18 UTC 2017


This is an automated email from the git hooks/post-receive script.

mans0954 pushed a commit to tag v0.1.1
in repository willow.

commit 01bccd8b448eb29d680bd74756276aad91f36d8d
Author: Karl Hobley <karlhobley10 at gmail.com>
Date:   Wed Feb 18 15:59:39 2015 +0000

    Added loader for .bmp files
---
 willow/image.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/willow/image.py b/willow/image.py
index e9be6de..7c62be8 100644
--- a/willow/image.py
+++ b/willow/image.py
@@ -170,14 +170,14 @@ def setup(cls):
     cls.register_backend(OpenCVBackend)
 
 
-    # Pillow is very good at loading PNG and JPEG files
-    cls.register_loader(['.png', '.jpg', '.jpeg'], PillowBackend, priority=100)
+    # Pillow is very good at loading PNG, JPEG and BMP files
+    cls.register_loader(['.png', '.jpg', '.jpeg', '.bmp'], PillowBackend, priority=100)
 
     # Pillow can load gifs too, but without animation
     cls.register_loader('.gif', PillowBackend, priority=-100)
 
-    # Wand can load PNG, JPEG and GIF (with animation), but doesn't work as fast as Pillow
-    cls.register_loader(['.png', '.jpg', '.jpeg', '.gif'], WandBackend)
+    # Wand can load PNG, JPEG, BMP and GIF (with animation), but doesn't work as fast as Pillow
+    cls.register_loader(['.png', '.jpg', '.jpeg', '.bmp', '.gif'], WandBackend)
 
 
 setup(Image)

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/willow.git



More information about the Python-modules-commits mailing list